@@ -5,6 +5,7 @@ from fastq files and upload to minotour.
 import logging
 import os
 import sys
+from collections import defaultdict
 
 from minFQ.endpoints import EndPoint
 from minFQ.minotourapi import MinotourAPI
@@ -231,7 +232,6 @@ class RunDataTracker:
         if not run:
             # get or create a flowcell
             log.info("Looking for flowcell {}".format(flowcell_name))
-            log.debug(flowcell)
             is_barcoded = True if "barcode" in description_dict.keys() else False
             has_fastq = False if self.args.skip_sequence else True
             key = "sample_id" if "sample_id" in description_dict else "sampleid"
@@ -271,6 +271,8 @@ class RunDataTracker:
         """
         if self.read_list:
             self.minotour_api.post(EndPoint.READS, json=self.read_list)
+        for read in self.read_list:
+            self.sequencing_statistics.fastq_info[read["run_id"]]["reads_uploaded"] += 1
         self.sequencing_statistics.reads_uploaded += len(self.read_list)
         # Refresh the read list
         self.read_list = []
